gchecky.model.pickup_t

Package gchecky :: Module model :: Class pickup_t |
[hide private]
[frames] | no frames]

# Class pickup_t

source code

    object --+
             |
     gxml.Node --+
                 |
                pickup_t

Nested Classes | [hide private]
Inherited from `gxml.Node`: `__metaclass__`

Instance Methods | [hide private]
Inherited from `gxml.Node`: `__eq__`, `__init__`, `read`, `write` Inherited from `object`: `__delattr__`, `__getattribute__`, `__hash__`, `__reduce__`, `__reduce_ex__`, `__repr__`, `__setattr__`, `__str__`

Class Methods | [hide private]
Inherited from `gxml.Node`: `fields`, `set_fields`

Static Methods | [hide private]
Inherited from `gxml.Node`: `__new__`

Class Variables | [hide private]
| name = `String:PATH(@name):REQ`
| price = `Node:PATH(price):REQ:{ price_t }`
| _fields = ``{``'``name``'``:` String:PATH(@name):REQ`,` `'``price``'``:` Node:PATH(`...`` list of meta-Fields of this class.

Properties | [hide private]
Inherited from `object`: `__class__`

Class Variable Details | [hide private]

  ### _fields list of meta-Fields of this class. Value:
      {'name': String:PATH(@name):REQ,
       'price': Node:PATH(price):REQ:{ price_t }}